% example12_6.m
% ODE_laplace
% This program solves a system of 2 differential equations
% by using ode45 function. The problem is to determine the
% y(t)positions of a mass in a mass-spring-dashpot system
% Y1=y, Y2=v, Y1'=Y2, Y2'=5*sin 2t-3Y2-2Y1 
% y(0)=1.0, y'(0)=-4.0
clear; clc;
initial=[1.0 -4.0];
tspan=0.0:0.1:20;
tol1=1.0e-6;
tol2=[1.0e-6 1.0e-6];
options=odeset('RelTol',tol1,'AbsTol',tol2);
[t,Y]=ode45('dYdt_laplace',tspan,initial,options);
P=[t Y];
dt=0.1;
for i=1:201
    t1=(i-1)*dt;
    ylp(i)=1.75*exp(-2*t1)-0.75*cos(2*t1)-0.25*sin(2*t1);
end    
plot(t,Y(:,1),t,ylp,'x'),
xlabel('t'),ylabel('y,ylp'),title('y and ylp vs. t'), grid;
text(1.0,0.92,'x-solution by Laplace transforms'),
text(10.0,0.92,'solid line-solution by ode45'); 
