% example12_7.m
% ODE_laplace2
% This program solves a system of 2 differential equations
% by using ode45 function. The problem is to determine the
% y(t)positions of a mass in a mass-spring-dashpot system
% Y1=y, Y2=v, Y1'=Y2, Y2'=5*t-3Y2-2Y1, for t < 2,
% Y2'=-3Y2-2Y1, for t >= 2,
% y(0)=1.0, y'(0)=0
clear; clc;
initial=[1.0 0.0];
tspan=0.0:0.1:4;
tol1=1.0e-6;
tol2=[1.0e-6 1.0e-6];
options=odeset('RelTol',tol1,'AbsTol',tol2);
[t,Y]=ode45('dYdt_laplace2',tspan,initial,options);
P=[t Y];
% Solution by Laplace Transforms
dt=0.1;
for i=1:41
    t1(i)=(i-1)*dt;
    t2=(i-1)*dt;
    if t2 < 2
        ylp(i)=2.5*t2-15/4-9/4*exp(-2*t2)+7*exp(-t2);
    end
    if t2 >= 2
        ylp(i)=-(9/4+15/4*exp(4))*exp(-2*t2)+(7+5*exp(2))*exp(-t2);
    end    
end 
 
plot(t,Y(:,1),t1,ylp,'x'),
xlabel('t'),ylabel('y,ylp'),title('y & ylp vs. t'), grid, 
legend('solution by ODE45','solution by Laplace Transforms');
 
