% example9_4.m
% optim_shafts
% Two machine shops, Machine Shop A and Machine Shop B, are to manufacture 
% two types shafts, shaft S1 and shaft S2. Each Machine shop has two
% Turning Machines, Turning Machine T1 and Turning Machine T2. The following
% table lists the production time for each shaft type on each machine and at
% each location.   
%
%----------------------------------------------|
% 	             TIME IN MINUTES               |
%----------|-----------------||----------------|
%          |  MACHINE SHOP A || MACHINE SHOP B |
% ---------|-----------------||----------------|
%  TURNING |      SHAFTS     ||   SHAFTS       |
%  MACHINE |                 ||                |
%----------|--------|--------||--------|-------|
%          |   S1   |   S2   ||   S1   |   S2  |
% ---------|--------|--------||--------|-------|
%   T1     |   4    |    9   ||   5    |   8   |
% ---------|--------|--------||--------|-------|
%   T2     |   2    |    6   ||   3    |   5   |
% ---------|--------|--------||--------|-------|
%
% Shaft S1 sells for $35 and shaft S2 sells for $55.
% Determine the number of S1 and S2 shafts that should be produced at
% each machine shop and on each machine that will maximize the 
% revenue per hour.

% Let: 
% x(1)=the number of S1 shafts produced/hr by machine T1 by shop A 
% x(2)=the number of S2 shafts produced/hr by machine T1 by shop A 
% x(3)=the number of S1 shafts produced/hr by machine T2 by shop A 
% x(4)=the number of S2 shafts produced/hr by machine T2 by shop A 
% x(5)=the number of S1 shafts produced/hr by machine T1 by shop B 
% x(6)=the number of S2 shafts produced/hr by machine T1 by shop B 
% x(7)=the number of S1 shafts produced/hr by machine T2 by shop B 
% x(8)=the number of S2 shafts produced/hr by machine T2 by shop B 
%
% Z=the total revenue/hr for producing the shafts=35*(x(1)+x(3)+x(5)+x(7))+
%   55*(x(2)+x(4)+x(6)+x(8)).
% The problem is to maximize Z subject to the following constraints
%   4*x(1)+9*x(2) <= 60
%   2*x(3)+6*x(4) <= 60
%   5*x(5)+8*x(6) <= 60
%   3*x(7)+5*x(8) <= 60

clc; 
fo=fopen('shaftoutput.dat','w');
fprintf(fo,'optim_shafts.m \n');
fprintf(fo,'Shaft Productiion Problem \n');
fprintf(fo,'This program maximizes the revenue/hr for the production \n');
fprintf(fo,'of two types of shafts, type S1 and type S2. There are two \n');
fprintf(fo,'machine shops producing these shafts, shop A & shop B. \n'); 
fprintf(fo,'Each shop has two types of turning machines, T1 and T2, \n');
fprintf(fo,'capable of producing these shafts. \n');

fprintf(fo,'Shop A: \n');
fprintf(fo,'  Machine T1 takes 4 minutes to produce type S1 shafts \n');
fprintf(fo,'  and 9 minutes to produce type S2 shafts. \n')
fprintf(fo,'  Machine T2 takes 2 minutes to produce type S1 shafts \n');
fprintf(fo,'  and 6 minutes to produce type S2 shafts. \n');

fprintf(fo,'Shop B: \n');
fprintf(fo,'  Machine T1 takes 5  minutes to produce type S1 shafts \n');
fprintf(fo,'  and 8 minutes to produce type S2 shafts. \n')
fprintf(fo,'  Machine T2 takes 3 minutes to produce type S1 shaft \n');
fprintf(fo,'  and 5 minutes to produce type S2 shafts. \n');

fprintf(fo,'Shaft S1 sells for $35 & shaft S2 sells for $55. \n');

fprintf(fo,'We wish to determine the number of S1 & S2 tanks that \n');
fprintf(fo,'should be produced at each shop and by each machine \n');
fprintf(fo,'that will maximize the revenue/hr for producing these shafts \n');

fprintf(fo,'Let x(1)=the number of S1 shafts produced/hr by machine T1 by shop A \n'); 
fprintf(fo,'    x(2)=the number of S2 shafts produced/hr by machine T1 by shop A \n');
fprintf(fo,'    x(3)=the number of S1 shafts produced/hr by machine T2 by shop A \n');
fprintf(fo,'    x(4)=the number of S2 shafts produced/hr by machine T2 by shop A \n');
fprintf(fo,'    x(5)=the number of S1 shafts produced/hr by machine T1 by shop B \n');
fprintf(fo,'    x(6)=the number of S2 shafts produced/hr by machine T1 by shop B \n');
fprintf(fo,'    x(7)=the number of S1 shafts produced/hr by machine T2 by shop B \n');
fprintf(fo,'    x(8)=the number of S2 shafts produced/hr by machine T2 by shop B \n');

fprintf(fo,'Let Z=the total revenue/hr for producing these tanks  \n');
fprintf(fo,' Z=35*(x(1)+x(3)+x(5)+x(7))+55*(x(2)+x(4)+x(6)+x(8)) \n');

% Take a guess at the solution
xo = [10 10 10 10 10 10 10 10];
LB = [0 0 0 0 0 0 0 0];
UB = [];

% We have linear inequality constraints
A=[4 9 0 0 0 0 0 0;
   0 0 2 6 0 0 0 0;
   0 0 0 0 5 8 0 0
   0 0 0 0 0 0 3 5];
B=[60 60 60 60]';

% We have no linear equality constraints, so pass [] for those arguments
% We have no equality or inequality nonlinear constraints,

[x, fval] = fmincon(@objtanks,xo,A,B,[],[],LB,UB);

fprintf(fo,'The number of S1 shafts produced by location A on machine M1=%5.0f\n',x(1));
fprintf(fo,'The number of S2 shafts produced by location A on machine M1=%5.0f\n',x(2));
fprintf(fo,'The number of S1 shafts produced by location A on machine M2=%5.0f\n',x(3));
fprintf(fo,'The number of S2 shafts produced by location A on machine M2=%5.0f\n',x(4));
fprintf(fo,'The number of S1 shafts produced by location B on machine M1=%5.0f\n',x(5));
fprintf(fo,'The number of S2 shafts produced by location B on machine M1=%5.0f\n',x(6));
fprintf(fo,'The number of S1 shafts produced by location B on machine M2=%5.0f\n',x(7));
fprintf(fo,'The number of S2 shafts produced by location B on machine M2=%5.0f\n',x(8));
fprintf(fo,'The revenue for producing these tanks = %8.0f \n',-fval);

fclose(fo);
